local _
local _G = _G

local artifactXP = _G.LibStub("LibDataBroker-1.1"):NewDataObject("Artifact", {
	type = "data source",
	icon = "Interface\\Icons\\Icon_UpgradeStone_legendary",
	label = "Artifact",
	title = "Artifact"
})

function artifactXP_GetNumArtifactTraitsPurchasableFromXP(pointsSpent, artifactXP)
  local numPoints = 0;
  local xpForNextPoint = C_ArtifactUI.GetCostForPointAtRank(pointsSpent);
  while artifactXP >= xpForNextPoint and xpForNextPoint > 0 do
	artifactXP = artifactXP - xpForNextPoint;
	
	pointsSpent = pointsSpent + 1;
	numPoints = numPoints + 1;
	
	xpForNextPoint = C_ArtifactUI.GetCostForPointAtRank(pointsSpent);
  end
  return numPoints, artifactXP, xpForNextPoint;
end

function artifactXP_PopulateValues()
  local itemID, altItemID, name, icon, totalXP, pointsSpent, quality, artifactAppearanceID, appearanceModID, itemAppearanceID, altItemAppearanceID, altOnTop = C_ArtifactUI.GetEquippedArtifactInfo();
  
  local numPointsAvailableToSpend, xp, xpForNextPoint = artifactXP_GetNumArtifactTraitsPurchasableFromXP(pointsSpent, totalXP)
  
  artifactXP.icon = icon
  
  if ( xpForNextPoint > 0 ) then
	if ( numPointsAvailableToSpend > 0 ) then
		artifactXP.text = string.format("%d/%d AP (|cffff0000+%d|r)", xp, xpForNextPoint, numPointsAvailableToSpend)
	else
		artifactXP.text = string.format("%d/%d AP", xp, xpForNextPoint)
		artifactXP.value = string.format("%d", xp)
		artifactXP.suffic = "AP"
	end
  end
  
end

artifactXP.OnTooltipShow = function(tooltip)
  local itemID, altItemID, name, icon, totalXP, pointsSpent, quality, artifactAppearanceID, appearanceModID, itemAppearanceID, altItemAppearanceID, altOnTop = C_ArtifactUI.GetEquippedArtifactInfo();
  local numPointsAvailableToSpend, xp, xpForNextPoint = artifactXP_GetNumArtifactTraitsPurchasableFromXP(pointsSpent, totalXP)
  tooltip:SetText(name, HIGHLIGHT_FONT_COLOR:GetRGB())
  tooltip:AddLine(" ");
  tooltip:AddLine(ARTIFACT_POWER_TOOLTIP_TITLE:format(BreakUpLargeNumbers(totalXP), BreakUpLargeNumbers(xp), BreakUpLargeNumbers(xpForNextPoint)));
  tooltip:AddLine(" ");
  tooltip:AddLine(ARTIFACT_POWER_TOOLTIP_BODY:format(numPointsAvailableToSpend), nil, nil, nil, true);
  tooltip:AddLine(" ");
  tooltip:AddLine("Use Shift+Click to send the current Artifact XP to the chat window", nil, nil, nil, true)
end

artifactXP.OnClick = function(frame, button)
	if button == "LeftButton" then
		if IsShiftKeyDown() then
			-- do stuff to send ArtifactXP to chat
			local itemID, altItemID, name, icon, totalXP, pointsSpent, quality, artifactAppearanceID, appearanceModID, itemAppearanceID, altItemAppearanceID, altOnTop = C_ArtifactUI.GetEquippedArtifactInfo();
			local numPointsAvailableToSpend, xp, xpForNextPoint = artifactXP_GetNumArtifactTraitsPurchasableFromXP(pointsSpent, totalXP)
			if ( numPointsAvailableToSpend > 0 ) then
				DEFAULT_CHAT_FRAME.editBox:SetText(string.format("%s: %d/%d (Rank %d+%d)", name, xp, xpForNextPoint, pointsSpent, numPointsAvailableToSpend))
			else 
				DEFAULT_CHAT_FRAME.editBox:SetText(string.format("%s: %d/%d (Rank %d)", name, xp, xpForNextPoint, pointsSpent))
			end
		else
			ArtifactFrame_LoadUI()
			if ( ArtifactFrame:IsVisible() ) then
				HideUIPanel(ArtifactFrame)
			else
				SocketInventoryItem(16);
			end
		end
	end
end

local ldbArtifactFrame = CreateFrame("Frame", "LDBArtifact")
ldbArtifactFrame:RegisterEvent("PLAYER_ENTERING_WORLD")
ldbArtifactFrame:RegisterEvent("ARTIFACT_XP_UPDATE")
ldbArtifactFrame:RegisterEvent("ARTIFACT_CLOSE")
ldbArtifactFrame:RegisterEvent("ARTIFACT_RESPEC_PROMPT")
ldbArtifactFrame:RegisterEvent("UNIT_INVENTORY_CHANGED")

local function eventHandler(self, event, ...)

  if ( HasArtifactEquipped() ) then
    artifactXP_PopulateValues()
  end
  
end

ldbArtifactFrame:SetScript("OnEvent", eventHandler)